<TS version="2.1" language="cy">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Clic-dde i olygu cyfeiriad neu label</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Creu cyfeiriad newydd</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Newydd</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Copïo</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">C&amp;au</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Dileu'r cyfeiriad presennol wedi ei ddewis o'r rhestr</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Cyfeiriad neu label i chwilio</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Allforio'r data yn y tab presennol i ffeil</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Allforio</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Dileu</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Dewis y cyfeiriad i yrru'r arian</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Dewis y cyfeiriad i dderbyn arian</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">D&amp;ewis</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Rhain ydi eich cyfeiriadau Bitcoin ar gyfer gyrru taliadau. Gwnewch yn sicr o'r swm a'r cyfeiriad derbyn cyn gyrru arian.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Dyma'ch cyfeiriadau Bitcoin ar gyfer derbyn taliadau. Defnyddiwch y botwm 'Creu cyfeiriad derbyn newydd' yn y tab derbyn i greu cyfeiriadau newydd. Dim ond gyda chyfeiriadau o'r math 'etifeddol' y mae llofnodi yn bosibl.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Copïo Cyfeiriad</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Copïo &amp;Label</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Golygu</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Allforio Rhestr Cyfeiriadau</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Ffeil wedi'i separeiddio gan gomau</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Roedd camgymeriad yn trïo safio'r rhestr gyfeiriadau i'r %1. Triwch eto os gwelwch yn dda.</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">Anfon cyfeiriadau - %1</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">Derbyn cyfeiriadau - %1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Methu Allforio</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation type="unfinished">Cyfeiriad</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(dim label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Deialog Cyfrinair</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Teipiwch gyfrinymadrodd</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Cyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Ailadroddwch gyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Dangos y geiriau pas</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Amgryptio'r Waled</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Mae'r weithred hon angen eich cyfrinair waled i ddatgloi'r waled.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Datgloi'r waled</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Newid cyfrinair</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Cadarnhau amgryptio'r waled</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Rhybudd: Os ydych yn amgryptio'r waled ag yn colli'r cyfrinair, byddwch yn &lt;b&gt; COLLI EICH BITCOINS I GYD &lt;b&gt; !</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Ydych yn siwr eich bod eisiau amgryptio eich waled?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Waled wedi amgryptio</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Nodwch y geiriau pas newydd ar gyfer y waled.&lt;br/&gt;Defnyddiwch geiriau pas o&lt;b&gt;ddeg neu fwy o gymeriadau ar hap&lt;/b&gt;neu&lt;b&gt;wyth neu fwy o eiriau&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Nodwch y geiriau pas hen a'r geiriau pas newydd ar gyfer y waled.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Parhau</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished">Yn ôl</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Cofiwch nad yw cryptio eich waled yn gallu amddiffyn eich bitcoiniodd yn llawn rhag cael eu dwyn gan feddalwedd ymosodol sy'n heintio eich cyfrifiadur.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Waled i'w amgryptio</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Mae eich waled ar fin cael ei chrypto.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Mae eich waled nawr wedi'i chrypto.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">PWYSIG: Mi ddylai unrhyw back ups blaenorol rydych wedi ei wneud o ffeil eich waled gael ei ddiweddaru efo'r ffeil amgryptiedig newydd ei chreu. Am resymau diogelwch, bydd back ups blaenorol o ffeil y walet heb amgryptio yn ddiwerth mor fuan ac yr ydych yn dechrau defnyddio'r waled amgryptiedig newydd.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Amgryptio waled wedi methu</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Amgryptio waled wedi methu oherwydd gwall mewnol. Dydi eich waled heb amgryptio.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Nid ydi'r cyfrineiriau a gyflenwyd yn cyfateb.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Dadgloi waled wedi methu</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Mae'r cyfrinair ysgrifennwyd ar gyfer datgryptio'r waled yn anghywir.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">Mae'r geiriau pas a nodwyd ar gyfer dad-cryptio'r waled yn anghywir. Mae'n cynnwys cymeriad null (hynny yw - bytsyn sero). Os gosodwyd y geiriau pas gyda fersiwn o'r meddalwedd hon cyn 25.0, ceisiwch eto gyda dim ond y cymeriadau hyd at — ond heb gynnwys — y cymeriad null cyntaf. Os yw hyn yn llwyddiannus, gosodwch geiriau pas newydd er mwyn osgoi'r broblem hon yn y dyfodol.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Newid cyfrinair waled yn llwyddiannus.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Method newid geiriau pas wedi methu</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">Mae'r geiriau pas hen a nodwyd ar gyfer dad-cryptio'r waled yn anghywir. Mae'n cynnwys cymeriad null (hynny yw - bytsyn sero). Os gosodwyd y geiriau pas gyda fersiwn o'r meddalwedd hon cyn 25.0, ceisiwch eto gyda dim ond y cymeriadau hyd at — ond heb gynnwys — y cymeriad null cyntaf.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Rhybudd: Mae allwedd Caps Lock ymlaen!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP/Rhwydfwgwd</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Gwaharddwyd Nes</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">Efallai bod ffeil y gosodiadau %1 yn llwgr neu'n anilys.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Eithriad ymladd</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Digwyddodd gwall angheuol.%1ni all barhau'n ddiogel mwyach a bydd yn cau.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Gwall mewnol</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Digwyddodd gwall mewnol.%1bydd yn ceisio parhau'n ddiogel.Mae hwn yn fwydyn annisgwyl y gellir ei adrodd fel y disgrifir isod.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">A ydych chi eisiau adfer gosodiadau i'r gwerthoedd diffinio, neu beidio â gwneud newidiadau a stopio?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Digwyddodd gwall angheuol. Gwiriwch fod y ffeil gosodiadau yn ysgrifenadwy, neu ceisiwch redeg gyda -nosettings.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished"> Gwall: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1ni wnaeth fynd allan yn ddiogel eto…</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Cyfanswm</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="unfinished">%1 a %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Trosolwg</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Dangos trosolwg cyffredinol y waled</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Trafodion</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Pori hanes trafodion</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">A&amp;llanfa</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Gadael rhaglen</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Ynghylch %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Dangos gwybodaeth am %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Ynghylch &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Dangos gwybodaeth am Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Addasu ffurfweddiad dewisiadau ar gyfer %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Creu waled newydd</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Lleihau</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Waled:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Gweithgaredd rhwydwaith wedi anablu.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Mae'r procsï yw&lt;b&gt;wedi'i alluog&lt;/b&gt;i:%1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Anfon arian i gyfeiriad Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Bacio fyny'r waled i leoliad arall</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Newid y cyfrinair ddefnyddiwyd ar gyfer amgryptio'r waled</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Anfon</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Derbyn</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Opsiynau…</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Crypto Waled…</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Amgryptio'r allweddi preifat sy'n perthyn i'ch waled</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;Bendith Waled…</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Newid Geiriau Pas…</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Llofnodi &amp;neges…</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Arwyddo negeseuon gyda eich cyfeiriadau Bitcoin i brofi mae chi sy'n berchen arnynt</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Gwirio neges…</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Gwirio negeseuon i sicrhau eu bod wedi eu harwyddo gyda cyfeiriadau Bitcoin penodol</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">&amp;Llwytho PSBT o ffeil…</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">Agor &amp;URI…</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Cau Waled…</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Creu Waled…</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Cau Pob Waled…</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Ffeil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Gosodiadau</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Cymorth</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Bar offer tabiau</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">Cydamseru Pennawdau (%1%)…</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Cydamseru gyda'r rhwydwaith…</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Indecsio blociau ar ddisg…</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Prosesu blociau ar ddisg…</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Cysylltu â chydweithwyr…</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Gofyn taliadau (creu côd QR a bitcoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Dangos rhestr o gyfeiriadau danfon a labelau wedi eu defnyddio</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Dangos rhestr o gyfeiriadau derbyn a labelau wedi eu defnyddio</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Dewisiadau Gorchymyn-llinell</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 Tu ôl</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">Yn dal i fyny…</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Cafodd y bloc olaf i'w dderbyn ei greu %1 yn ôl.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Ni fydd trafodion ar ôl hyn yn weledol eto.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Gwall</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Rhybudd</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Gwybodaeth</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Cyfamserol</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">Llwytho Trafodiad Bitcoin wedi'i Llofnodi'n Rhanol</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">Llwytho PSBT o &amp;glipbwrdd…</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">Llwytho Trafodiad Bitcoin wedi'i Llofnodi'n Rhanol o glipbwrdd</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Ffenestr Nod</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">Agor y consol dadfygio a diagnostig nod</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Anfon cyfeiriadau</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Derbyn cyfeiriadau</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Agor bitcoin: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Agor Waled</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Agor waled</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Cau waled</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">Ail-adfer Waled…</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">Adfer waled o ffeil wrth gefn</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Cau pob waled</translation>
    </message>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Mudo Waled</translation>
    </message>
    <message>
        <source>Migrate a wallet</source>
        <translation type="unfinished">Mudo waled</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Dangos y%1neges gymorth i gael rhestr gyda'r opsiynau llinell-gorchymyn Bitcoin posibl</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;Masgio gwerthoedd</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">Masgio'r gwerthoedd yn y tab Trosolwg</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Dim waledi ar gael</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Data Waled</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">Llwytho Waled wrth Gefn</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">Ail-adfer Waled</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Enw'r Waled</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Ffenestr</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">Mwydo</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Ffenestr Brydferth</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1cwsmer</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;Cuddio</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">Dangos</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Cliciwch am fwy o weithredoedd.</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">Dangos tab Cydweithwyr</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Analluogi gweithgaredd rhwydwaith</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">Alluogi gweithgaredd rhwydwaith</translation>
    </message>
    <message>
        <source>Pre-syncing Headers (%1%)…</source>
        <translation type="unfinished">Cyn-syncronïo Penawdau (%1%)…</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished"> Gwall: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Rhybudd: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Dyddiad: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Cyfanswm: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Waled: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Math: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Cyfeiriad: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Trafodiad anfonwyd</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Trafodiad sy'n cyrraedd</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">Cynhyrchu allweddi HD wedi ei &lt;b&gt; alluogi &lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Cynhyrchu allweddi HD wedi'w &lt;b&gt; anablu &lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Allwedd breifat&lt;b&gt;analluog&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;heb ei gloi&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;ar glo&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">Neges wreiddiol:</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">Uned i ddangos symiau ynddi. Cliciwch i ddewis uned arall.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">Dewis Ceiniog</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Maint:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Maint</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Cyfanswm:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Ffî:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Ar Ôl Ffî</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Newid:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(d)dewis popeth</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Cyfanswm</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Derbynwyd gyda label</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Derbynwyd gyda chyfeiriad</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dyddiad</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Cadarnhadiadau</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Cadarnhawyd</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Copïo Cyfanswm</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Copïo cyfeiriad</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Copïo &amp;label</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Copïo &amp;swm</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">Copïo &amp;ID trafodiad a chyfryngau allbwn</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">L&amp;loi newid nad yw wedi'i wario</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Agor newid nad yw wedi'i wario</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Copïo maint</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Copïo ffi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Copïo ar ôl ffi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Copïo bytiau</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Copïo newid</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1caeedig</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation type="unfinished">Gall amrywio +/-%1satoshi(s) y tu mewn.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(dim label)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation type="unfinished">newid o%1(%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(newid)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Creu Waled</translation>
    </message>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation type="unfinished">Creu Waled&lt;b&gt;%1&lt;/b&gt;…</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation type="unfinished">Methwyd creu waled</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation type="unfinished">Creu rhybudd waled</translation>
    </message>
    <message>
        <source>Can't list signers</source>
        <translation type="unfinished">Methu â rhestru llofnodwyr</translation>
    </message>
    </context>
<context>
    <name>MigrateWalletActivity</name>
    <message>
        <source>Migrating the wallet will convert this wallet to one or more descriptor wallets. A new wallet backup will need to be made.
If this wallet contains any watchonly scripts, a new wallet will be created which contains those watchonly scripts.
If this wallet contains any solvable but not watched scripts, a different and new wallet will be created which contains those scripts.

The migration process will create a backup of the wallet before migrating. This backup file will be named &lt;wallet name&gt;-&lt;timestamp&gt;.legacy.bak and can be found in the directory for this wallet. In the event of an incorrect migration, the backup can be restored with the "Restore Wallet" functionality.</source>
        <translation type="unfinished">Bydd mudo'r waled yn trosi'r waled hon i un neu fwy o waledi disgrifydd. Bydd angen gwneud copi wrth gefn waled newydd.
Os yw'r waled hon yn cynnwys unrhyw sgriptiau gwylio yn unig, bydd waled newydd yn cael ei chreu sy'n cynnwys y sgriptiau gwylio yn unig hynny.
Os yw'r waled hon yn cynnwys unrhyw sgriptiau solvable ond heb eu gwylio, bydd waled gwahanol a newydd yn cael ei chreu sy'n cynnwys y sgriptiau hynny.
Bydd y broses fudo yn creu copi wrth gefn o'r waled cyn mudo. Bydd y ffeil wrth gefn hon yn cael ei henwi&lt;wallet name&gt;-&lt;timestamp&gt;.legacy.bak a gellir ei ddarganfod yn y cyfeiriadur ar gyfer y waled hon. Mewn achos o ymfudiad anghywir, gellir adfer y copi wrth gefn gyda'r swyddogaeth "Adfer Waled".</translation>
    </message>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Mudo Waled</translation>
    </message>
    <message>
        <source>The wallet '%1' was migrated successfully.</source>
        <translation type="unfinished">Y waled'%1' ymfudodd yn llwyddiannus.</translation>
    </message>
    <message>
        <source>Watchonly scripts have been migrated to a new wallet named '%1'.</source>
        <translation type="unfinished">Mae sgriptiau gwylio yn unig wedi'u symud i waled newydd o'r enw '%1'.</translation>
    </message>
    <message>
        <source>Solvable but not watched scripts have been migrated to a new wallet named '%1'.</source>
        <translation type="unfinished">Mae sgriptiau hydoddadwy ond heb eu gwylio wedi'u symud i waled newydd o'r enw '%1'.</translation>
    </message>
    <message>
        <source>Migration Successful</source>
        <translation type="unfinished">Mudo yn Llwyddiannus</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Agor Waled</translation>
    </message>
    </context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">Ail-adfer Waled</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Cau waled</translation>
    </message>
    <message>
        <source>Are you sure you wish to close the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">Ydych chi'n siŵr eich bod am gau'r waled&lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
    <message>
        <source>Closing the wallet for too long can result in having to resync the entire chain if pruning is enabled.</source>
        <translation type="unfinished">Gall cau'r waled am gyfnod rhy hir arwain at orfod ail-gydamseru'r gadwyn gyfan os yw tocio wedi'i alluogi.</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Cau pob waled</translation>
    </message>
    <message>
        <source>Are you sure you wish to close all wallets?</source>
        <translation type="unfinished">Ydych chi'n siŵr eich bod am gau pob waled?</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Creu Waled</translation>
    </message>
    <message>
        <source>You are one step away from creating your new wallet!</source>
        <translation type="unfinished">Rydych chi un cam i ffwrdd o greu eich waled newydd!</translation>
    </message>
    <message>
        <source>Please provide a name and, if desired, enable any advanced options</source>
        <translation type="unfinished">Rhowch enw ac, os dymunwch, galluogwch unrhyw opsiynau uwch</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Enw'r Waled</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Waled</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation type="unfinished">Amgryptio'r waled. Bydd y waled yn cael ei hamgryptio gyda chyfrinair o'ch dewis.</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Waled Amgryptio</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">Dewisiadau Uwch</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation type="unfinished">Analluogi allweddi preifat ar gyfer y waled hon. Ni fydd gan waledi ag allweddi preifat anabl unrhyw allweddi preifat ac ni allant gael hedyn HD nac allweddi preifat wedi'u mewnforio. Mae hyn yn ddelfrydol ar gyfer waledi gwylio yn unig.</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation type="unfinished">Gwnewch waled wag. Nid oes gan waledi gwag allweddi preifat na sgriptiau i ddechrau. Gellir mewnforio allweddi preifat a chyfeiriadau, neu gellir gosod hedyn HD, yn ddiweddarach.</translation>
    </message>
    <message>
        <source>Use an external signing device such as a hardware wallet. Configure the external signer script in wallet preferences first.</source>
        <translation type="unfinished">Defnyddiwch ddyfais arwyddo allanol fel waled caledwedd. Ffurfweddwch y sgript llofnodwr allanol yn y dewisiadau waled yn gyntaf.</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Creu</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Wedi'i lunio heb gefnogaeth arwyddo allanol (sy'n ofynnol ar gyfer llofnodi allanol)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Golygu'r cyfeiriad</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">Y label sy'n gysylltiedig â'r cofnod rhestr cyfeiriadau hwn</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation type="unfinished">Y cyfeiriad sy'n gysylltiedig â'r cofnod rhestr cyfeiriadau hwn. Dim ond ar gyfer anfon cyfeiriadau y gellir addasu hwn.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Cyfeiriad</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Cyfeiriad anfon newydd</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Golygu'r cyfeiriad derbyn</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Golygu'r cyfeiriad anfon</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation type="unfinished">Y cyfeiriad a roddwyd "%1Nid yw " yn gyfeiriad Bitcoin dilys.</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation type="unfinished">Cyfeiriad "%1" eisoes yn bodoli fel cyfeiriad derbyn gyda label "%2" ac felly ni ellir ei ychwanegu fel cyfeiriad anfon.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Methodd ddatgloi'r waled.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Methodd gynhyrchu allwedd newydd.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation type="unfinished">Bydd cyfeiriadur data newydd yn cael ei greu.</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="unfinished">enw</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation type="unfinished">Mae'r cyfeiriadur eisoes yn bodoli. Ychwanegu%1os ydych yn bwriadu creu cyfeiriadur newydd yma.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation type="unfinished">Mae'r llwybr eisoes yn bodoli, ac nid yw'n gyfeiriadur.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">Methu creu cyfeiriadur data yma.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">Dewisiadau llinell orchymyn</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Croeso</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Choose data directory</source>
        <translation type="unfinished">Dewiswch gyfeiriadur data</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation type="unfinished">O leiaf%1Bydd GB o ddata yn cael ei storio yn y cyfeiriadur hwn, a bydd yn tyfu dros amser.</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation type="unfinished">Oddeutu%1Bydd GB o ddata yn cael ei storio yn y cyfeiriadur hwn.</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Bitcoin block chain.</source>
        <translation type="unfinished">%1yn lawrlwytho ac yn storio copi o'r gadwyn bloc Bitcoin.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation type="unfinished">Bydd y waled hefyd yn cael ei storio yn y cyfeiriadur hwn.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation type="unfinished">Gwall: Cyfeiriadur data penodedig "%1" ni ellir ei greu.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Gwall</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Ffurflen</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <extracomment>Tooltip text for button that allows you to paste an address that is in your clipboard.</extracomment>
        <translation type="unfinished">Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation type="unfinished">&amp;Prif</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation type="unfinished">Cychwyn yn awtomatig%1ar ôl mewngofnodi i'r system.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation type="unfinished">&amp;Cychwyn%1ar mewngofnodi i'r system</translation>
    </message>
    <message>
        <source>Enabling pruning significantly reduces the disk space required to store transactions. All blocks are still fully validated. Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation type="unfinished">Mae galluogi torri'n sylweddol yn lleihau'r gofod disg sydd ei angen i storio trafodion. Mae pob bloc yn parhau i gael ei ddilysu'n llawn. Bydd adfer y gosodiad hwn yn gofyn am ailosodlawr y blwch cyfan.</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation type="unfinished">Maint y &amp;chache database</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation type="unfinished">Nifer o edafedd &amp;dilysu sgript</translation>
    </message>
    <message>
        <source>Full path to a %1 compatible script (e.g. C:\Downloads\hwi.exe or /Users/you/Downloads/hwi.py). Beware: malware can steal your coins!</source>
        <translation type="unfinished">Llwybr llawn i%1sgript gymhwysol (e.e. C:\Downloads\hwi.exe neu /Users/you/Downloads/hwi.py). Rhowch sylw: gall malware ddwyn eich ceiniogau!</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation type="unfinished">Cyfeiriad IP y brocsï (e.e. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Shows if the supplied default SOCKS5 proxy is used to reach peers via this network type.</source>
        <translation type="unfinished">Dangos os yw'r brocsï SOCKS5 diffiniedig a ddarparwyd yn cael ei ddefnyddio i gyrraedd cydweithwyr trwy'r math rhwydwaith hwn.</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation type="unfinished">Mewnosod yn lle cau'r cymhwysiad pan fydd y ffenestr yn cael ei chau. Pan fydd y dewis hwn yn cael ei alluogi, caiff y cymhwysiad ei gau dim ond ar ôl dewis Cau yn y ddewislen.</translation>
    </message>
    <message>
        <source>Font in the Overview tab: </source>
        <translation type="unfinished">Ffont yn y tab Trosolwg:</translation>
    </message>
    <message>
        <source>Options set in this dialog are overridden by the command line:</source>
        <translation type="unfinished">Mae opsiynau a osodir yn y ddeialog hon yn cael eu gorffenni gan y llinell orchymyn:</translation>
    </message>
    <message>
        <source>Open the %1 configuration file from the working directory.</source>
        <translation type="unfinished">Agor y%1ffilet gosodiad o'r directory gweithio.</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation type="unfinished">Agor Ffeil Gosodiad</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">Ailosod pob opsiwn cleient i'r rhagosodiad.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;Ailosod Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Rhwydwaith</translation>
    </message>
    <message>
        <source>Prune &amp;block storage to</source>
        <translation type="unfinished">Torri storfa &amp;bloc i</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation type="unfinished">Bydd ailosod y gosodiad hwn yn gofyn am ailosodlawr y gadwyn floc gyfan.</translation>
    </message>
    <message>
        <source>Set the number of script verification threads. Negative values correspond to the number of cores you want to leave free to the system.</source>
        <extracomment>Tooltip text for Options window setting that sets the number of script verification threads. Explains that negative values mean to leave these many cores free to the system.</extracomment>
        <translation type="unfinished">Gosod nifer yr edafedd dilysu sgript. Mae gwerthoedd negyddol yn cyfateb i nifer y craidd rydych chi am eu gadael yn rhydd i'r system.</translation>
    </message>
    <message>
        <source>(0 = auto, &lt;0 = leave that many cores free)</source>
        <translation type="unfinished">(0 = awto, &lt;0 = gadael cymaint o greiddiau'n rhydd)</translation>
    </message>
    <message>
        <source>This allows you or a third party tool to communicate with the node through command-line and JSON-RPC commands.</source>
        <extracomment>Tooltip text for Options window setting that enables the RPC server.</extracomment>
        <translation type="unfinished">Mae hyn yn eich galluogi chi neu offer trydydd parti i gyfathrebu gyda'r nod trwy orchmynion llinell orchymyn a JSON-RPC.</translation>
    </message>
    <message>
        <source>Enable R&amp;PC server</source>
        <extracomment>An Options window setting to enable the RPC server.</extracomment>
        <translation type="unfinished">Galluogi gweinydd R&amp;PC</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">W&amp;aled</translation>
    </message>
    <message>
        <source>Whether to set subtract fee from amount as default or not.</source>
        <extracomment>Tooltip text for Options window setting that sets subtracting the fee from a sending amount as default.</extracomment>
        <translation type="unfinished">A ddylid gosod y tynnu ffioedd o'r swm fel y rhagosodiad ai peidio.</translation>
    </message>
    <message>
        <source>Subtract &amp;fee from amount by default</source>
        <extracomment>An Options window setting to set subtracting the fee from a sending amount as default.</extracomment>
        <translation type="unfinished">Tynnu &amp;ffi o'r swm fel y rhagosodiad</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation type="unfinished">Arbenigwr</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation type="unfinished">Galluogi nodweddion &amp;rheoli ceiniogau</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation type="unfinished">Os gwnewch chi analluogi gwario newid nad yw wedi’i gadarnhau, ni ellir defnyddio’r newid o drafodiad nes bod y trafodiad hwnnw wedi cael o leiaf un cadarnhad. Mae hyn hefyd yn effeithio ar sut y cyfrifir eich balans.</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation type="unfinished">&amp;Gwario newid nad yw wedi’i gadarnhau</translation>
    </message>
    <message>
        <source>Enable &amp;PSBT controls</source>
        <extracomment>An options window setting to enable PSBT controls.</extracomment>
        <translation type="unfinished">Galluogi &amp;rheolaethau PSBT</translation>
    </message>
    <message>
        <source>Whether to show PSBT controls.</source>
        <extracomment>Tooltip text for options window setting that enables PSBT controls.</extracomment>
        <translation type="unfinished">A ddylid dangos rheolaethau PSBT.</translation>
    </message>
    <message>
        <source>External Signer (e.g. hardware wallet)</source>
        <translation type="unfinished">Llofnodwr Allanol (e.e. waled caledwedd)</translation>
    </message>
    <message>
        <source>&amp;External signer script path</source>
        <translation type="unfinished">Llwybr sgript llofnodwr &amp;allanol</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation type="unfinished">Derbyn cysylltiadau o'r tu allan.</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation type="unfinished">Caniatáu cysylltiadau sy'n dod i mewn</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
        <translation type="unfinished">Cysylltu â rhwydwaith Bitcoin trwy brocsï SOCKS5.</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation type="unfinished">&amp;Cysylltu trwy brocsï SOCKS5 (brocsï rhagosodiad):</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation type="unfinished">&amp;IP y brocsï:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation type="unfinished">&amp;Porth:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation type="unfinished">Porth y brocsï (e.e. 9050)</translation>
    </message>
    <message>
        <source>Used for reaching peers via:</source>
        <translation type="unfinished">Defnyddir ar gyfer cyrraedd cyd-fyfyrwyr trwy:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Ffenestr</translation>
    </message>
    <message>
        <source>Show the icon in the system tray.</source>
        <translation type="unfinished">Dangos yr eicon yn y tray system.</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished">&amp;Dangos</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Wedi'i lunio heb gefnogaeth arwyddo allanol (sy'n ofynnol ar gyfer llofnodi allanol)</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Parhau</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Gwall</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Ffurflen</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Cyfeiriad</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Math</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Rhwydwaith</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">Gwybodaeth</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Rhwydwaith</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Ffenestr Nod</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Agor</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">&amp;Copïo cyfeiriad</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Copïo cyfeiriad</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Copïo &amp;label</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Copïo &amp;swm</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Methodd ddatgloi'r waled.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Cyfanswm:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Neges:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Waled:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;Cyfeiriad Copi</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dyddiad</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Neges</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(dim label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Anfon arian</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Maint:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Maint</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Cyfanswm:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Ffî:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Ar Ôl Ffî</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Newid:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation type="unfinished">Anfon at pobl lluosog ar yr un pryd</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation type="unfinished">Gweddill:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation type="unfinished">Cadarnhau'r gweithrediad anfon</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Copïo maint</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Copïo Cyfanswm</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Copïo ffi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Copïo ar ôl ffi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Copïo bytiau</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Copïo newid</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="unfinished">%1 i %2</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(dim label)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;Maint</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Neges:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dyddiad</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Neges</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Cyfanswm</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Math</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(dim label)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation type="unfinished">Heddiw</translation>
    </message>
    <message>
        <source>This week</source>
        <translation type="unfinished">Yr wythnos hon</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">Y mis hwn</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation type="unfinished">Mis diwethaf</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">Eleni</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Copïo cyfeiriad</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Copïo &amp;label</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Copïo &amp;swm</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Ffeil wedi'i separeiddio gan gomau</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Cadarnhawyd</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Math</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Cyfeiriad</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Methu Allforio</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Creu waled newydd</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Gwall</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Anfon arian</translation>
    </message>
    <message>
        <source>Current fee:</source>
        <translation type="unfinished">Ffi gyfredol</translation>
    </message>
    <message>
        <source>Increase:</source>
        <translation type="unfinished">Cynydd:</translation>
    </message>
    <message>
        <source>New fee:</source>
        <translation type="unfinished">Ffi newydd:</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Allforio</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Allforio'r data yn y tab presennol i ffeil</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Data Waled</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Unable to bind to %s on this computer. %s is probably already running.</source>
        <translation type="unfinished">Methu cysylltu â%sar y cyfrifiadur hwn.%syn debyg eisoes yn rhedeg.</translation>
    </message>
    <message>
        <source>Unable to create the PID file '%s': %s</source>
        <translation type="unfinished">Methu creu'r ffeil PID '%s':%s</translation>
    </message>
    <message>
        <source>Unable to find UTXO for external input</source>
        <translation type="unfinished">Methu dod o hyd i UTXO ar gyfer mewnbwn allanol</translation>
    </message>
    <message>
        <source>Unable to open %s for writing</source>
        <translation type="unfinished">Methu agor%sar gyfer ysgrifennu</translation>
    </message>
    <message>
        <source>Unable to parse -maxuploadtarget: '%s'</source>
        <translation type="unfinished">Methu dadansoddi -maxuploadtarget: '%s'</translation>
    </message>
    <message>
        <source>Unable to start HTTP server. See debug log for details.</source>
        <translation type="unfinished">Methu cychwyn gweinydd HTTP. Gweler y log dadfygio am fanylion.</translation>
    </message>
    <message>
        <source>Unknown -blockfilterindex value %s.</source>
        <translation type="unfinished">Gwerth -blockfilterindex anhysbys%s.</translation>
    </message>
    <message>
        <source>Unknown address type '%s'</source>
        <translation type="unfinished">Math cyfeiriad anhysbys '%s'</translation>
    </message>
    <message>
        <source>Unknown change type '%s'</source>
        <translation type="unfinished">Math newid anhysbys '%s'</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation type="unfinished">Rhyngrwyd anhysbys wedi'i bennu yn -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Unknown new rules activated (versionbit %i)</source>
        <translation type="unfinished">Reolau newydd anhysbys wedi'u gweithredu (versionbit%i)</translation>
    </message>
    <message>
        <source>Unrecognised option "%s" provided in -test=&lt;option&gt;.</source>
        <translation type="unfinished">Opcsiwn annasarnhaol "%s "a ddarparwyd yn -test=&lt;option&gt;.</translation>
    </message>
    <message>
        <source>Unsupported global logging level %s=%s. Valid values: %s.</source>
        <translation type="unfinished">Llefel logio global nad yw'n cael ei gefnogi%s=%s.Gwerthoedd dilys:%s.</translation>
    </message>
    <message>
        <source>Wallet file creation failed: %s</source>
        <translation type="unfinished">Methwyd creu ffeil y waled:%s</translation>
    </message>
    <message>
        <source>acceptstalefeeestimates is not supported on %s chain.</source>
        <translation type="unfinished">nid yw acceptstalefeeestimates yn cael ei gefnogi ar%scadwyn.</translation>
    </message>
    <message>
        <source>Unsupported logging category %s=%s.</source>
        <translation type="unfinished">Categori logio nad yw'n cael ei gefnogi%s=%s.</translation>
    </message>
    <message>
        <source>Error: Could not add watchonly tx %s to watchonly wallet</source>
        <translation type="unfinished">Gwall: Ni allwyd ychwanegu tx gwylio'n unig%si waled gwylio'n unig</translation>
    </message>
    <message>
        <source>Error: Could not delete watchonly transactions. </source>
        <translation type="unfinished">Gwall: Ni allwyd dileu trafodion gwylio'n unig.</translation>
    </message>
    <message>
        <source>User Agent comment (%s) contains unsafe characters.</source>
        <translation type="unfinished">Sylw Agent Defnyddiwr (%s) yn cynnwys cymeriadau anghyson.</translation>
    </message>
    <message>
        <source>Verifying blocks…</source>
        <translation type="unfinished">Wedi gwirio blociau…</translation>
    </message>
    <message>
        <source>Verifying wallet(s)…</source>
        <translation type="unfinished">Wedi gwirio'r waled(au)…</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart %s to complete</source>
        <translation type="unfinished">Roedd angen ailosod y waled:%si gwblhau</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">Ni allwyd darllen ffeil y gosodiadau</translation>
    </message>
    <message>
        <source>Settings file could not be written</source>
        <translation type="unfinished">Ni allwyd ysgrifennu ffeil y gosodiadau</translation>
    </message>
</context>
</TS>